==> mariadb-10.0.9.tar.gz: mariadb-10.0.9/storage/tokudb/tokudb_vlq.h <==
/* -*- mode: C++; c-basic-offset: 4; indent-tabs-mode: nil -*- */
// vim: ft=cpp:expandtab:ts=8:sw=4:softtabstop=4:
#ident "$Id$"
/*
COPYING CONDITIONS NOTICE:

  This program is free software; you can redistribute it and/or modify
  it under the terms of version 2 of the GNU General Public License as
  published by the Free Software Foundation, and provided that the
  following conditions are met:

      * Redistributions of source code must retain this COPYING
        CONDITIONS NOTICE, the COPYRIGHT NOTICE (below), the
        DISCLAIMER (below), the UNIVERSITY PATENT NOTICE (below), the
        PATENT MARKING NOTICE (below), and the PATENT RIGHTS
        GRANT (below).

      * Redistributions in binary form must reproduce this COPYING
        CONDITIONS NOTICE, the COPYRIGHT NOTICE (below), the
        DISCLAIMER (below), the UNIVERSITY PATENT NOTICE (below), the
        PATENT MARKING NOTICE (below), and the PATENT RIGHTS
        GRANT (below) in the documentation and/or other materials
        provided with the distribution.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.

COPYRIGHT NOTICE:

  TokuDB, Tokutek Fractal Tree Indexing Library.
  Copyright (C) 2007-2013 Tokutek, Inc.

DISCLAIMER:

  This program is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.

UNIVERSITY PATENT NOTICE:

  The technology is licensed by the Massachusetts Institute of
  Technology, Rutgers State University of New Jersey, and the Research
  Foundation of State University of New York at Stony Brook under
  United States of America Serial No. 11/760379 and to the patents
  and/or patent applications resulting from it.

PATENT MARKING NOTICE:

  This software is covered by US Patent No. 8,185,551.
  This software is covered by US Patent No. 8,489,638.

PATENT RIGHTS GRANT:

  "THIS IMPLEMENTATION" means the copyrightable works distributed by
  Tokutek as part of the Fractal Tree project.

  "PATENT CLAIMS" means the claims of patents that are owned or
  licensable by Tokutek, both currently or in the future; and that in
  the absence of this license would be infringed by THIS
  IMPLEMENTATION or by using or running THIS IMPLEMENTATION.

  "PATENT CHALLENGE" shall mean a challenge to the validity,
  patentability, enforceability and/or non-infringement of any of the
  PATENT CLAIMS or otherwise opposing any of the PATENT CLAIMS.

  Tokutek hereby grants to you, for the term and geographical scope of
  the PATENT CLAIMS, a non-exclusive, no-charge, royalty-free,
  irrevocable (except as stated in this section) patent license to
  make, have made, use, offer to sell, sell, import, transfer, and
  otherwise run, modify, and propagate the contents of THIS
  IMPLEMENTATION, where such license applies only to the PATENT
  CLAIMS.  This grant does not include claims that would be infringed
  only as a consequence of further modifications of THIS
  IMPLEMENTATION.  If you or your agent or licensee institute or order
  or agree to the institution of patent litigation against any entity
  (including a cross-claim or counterclaim in a lawsuit) alleging that
  THIS IMPLEMENTATION constitutes direct or contributory patent
  infringement, or inducement of patent infringement, then any rights
  granted to you under this License shall terminate as of the date
  such litigation is filed.  If you or your agent or exclusive
  licensee institute or order or agree to the institution of a PATENT
  CHALLENGE, then Tokutek may terminate any rights granted to you
  under this License.
*/

#ident "Copyright (c) 2007-2013 Tokutek Inc.  All rights reserved."
#ident "The technology is licensed by the Massachusetts Institute of Technology, Rutgers State University of New Jersey, and the Research Foundation of State University of New York at Stony Brook under United States of America Serial No. 11/760379 and to the patents and/or patent applications resulting from it."
#ifndef _TOKUDB_VLQ_H
#define _TOKUDB_VLQ_H

namespace tokudb {

    // Variable length encode an unsigned integer into a buffer with limit s.
    // Returns the number of bytes used to encode n in the buffer.
    // Returns 0 if the buffer is too small.
    template <class T> size_t vlq_encode_ui(T n, void *p, size_t s) {
        unsigned char *pp = (unsigned char *)p;
        size_t i = 0;
        while (n >= 128) {
            if (i >= s)
                return 0; // not enough space
            pp[i++] = n%128;
            n = n/128;
        }
        if (i >= s) 
            return 0; // not enough space
        pp[i++] = 128+n;
        return i;
    }

    // Variable length decode an unsigned integer from a buffer with limit s.
    // Returns the number of bytes used to decode the buffer.
    // Returns 0 if the buffer is too small.
    template <class T> size_t vlq_decode_ui(T *np, void *p, size_t s) {
        unsigned char *pp = (unsigned char *)p;
        T n = 0;
        size_t i = 0;
        while (1) {
            if (i >= s)
                return 0; // not a full decode
            T m = pp[i];
            n |= (m & 127) << (7*i);
            i++;
            if ((m & 128) != 0)
                break;
        }
        *np = n;
        return i;
    }
}

#endif

==> mariadb-10.0.33.tar.gz: mariadb-10.0.33/storage/tokudb/tokudb_vlq.h <==
/* -*- mode: C++; c-basic-offset: 4; indent-tabs-mode: nil -*- */
// vim: ft=cpp:expandtab:ts=8:sw=4:softtabstop=4:
#ident "$Id$"
/*======
This file is part of TokuDB


Copyright (c) 2006, 2015, Percona and/or its affiliates. All rights reserved.

    TokuDBis is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2,
    as published by the Free Software Foundation.

    TokuDB is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with TokuDB.  If not, see <http://www.gnu.org/licenses/>.

======= */

#ident "Copyright (c) 2006, 2015, Percona and/or its affiliates. All rights reserved."

#ifndef _TOKUDB_VLQ_H
#define _TOKUDB_VLQ_H

namespace tokudb {

    // Variable length encode an unsigned integer into a buffer with limit s.
    // Returns the number of bytes used to encode n in the buffer.
    // Returns 0 if the buffer is too small.
    template <class T> size_t vlq_encode_ui(T n, void *p, size_t s) {
        unsigned char *pp = (unsigned char *)p;
        size_t i = 0;
        while (n >= 128) {
            if (i >= s)
                return 0; // not enough space
            pp[i++] = n%128;
            n = n/128;
        }
        if (i >= s) 
            return 0; // not enough space
        pp[i++] = 128+n;
        return i;
    }

    // Variable length decode an unsigned integer from a buffer with limit s.
    // Returns the number of bytes used to decode the buffer.
    // Returns 0 if the buffer is too small.
    template <class T> size_t vlq_decode_ui(T *np, void *p, size_t s) {
        unsigned char *pp = (unsigned char *)p;
        T n = 0;
        size_t i = 0;
        while (1) {
            if (i >= s)
                return 0; // not a full decode
            T m = pp[i];
            n |= (m & 127) << (7*i);
            i++;
            if ((m & 128) != 0)
                break;
        }
        *np = n;
        return i;
    }
}

#endif
